summaryrefslogtreecommitdiff
path: root/src/libmbim-glib
diff options
context:
space:
mode:
authorAleksander Morgado <aleksander@aleksander.es>2021-01-10 14:40:31 +0100
committerAleksander Morgado <aleksander@aleksander.es>2021-01-10 14:43:41 +0100
commit701de6d7a09c7f8ad24f4f920daf49c7a7c56c7e (patch)
tree403a6f25074217b9df391bef884a8a69710dd8b5 /src/libmbim-glib
parentd3ed5f90589e640268356ef9809a25bb4c7d6282 (diff)
libmbim-glib,sar: renamed Transmission Status related enums
Removing the MS prefix, and some other minor changes.
Diffstat (limited to 'src/libmbim-glib')
-rw-r--r--src/libmbim-glib/mbim-enums.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/src/libmbim-glib/mbim-enums.h b/src/libmbim-glib/mbim-enums.h
index 524d570..8f27d6f 100644
--- a/src/libmbim-glib/mbim-enums.h
+++ b/src/libmbim-glib/mbim-enums.h
@@ -1253,37 +1253,37 @@ typedef enum { /*< since=1.26 >*/
* Since: 1.26
*/
typedef enum { /*< since=1.26 >*/
- MBIM_SAR_WIFI_HARDWARE_STATE_INTEGRATED = 0,
+ MBIM_SAR_WIFI_HARDWARE_STATE_INTEGRATED = 0,
MBIM_SAR_WIFI_HARDWARE_STATE_NOT_INTEGRATED = 1
} MbimSarWifiHardwareState;
/**
* MbimMsTransmissionNotification:
* @MBIM_MS_TRANSMISSION_NOTIFICATION_DISABLED: Notification disabled.
* @MBIM_MS_TRANSMISSION_NOTIFICATION_ENABLED: Notification enabled.
*
* Whether modem channel transmission status notification is disabled or enabled.
*
* Since: 1.26
*/
typedef enum { /*< since=1.26 >*/
- MBIM_MS_TRANSMISSION_NOTIFICATION_DISABLED = 0,
- MBIM_MS_TRANSMISSION_NOTIFICATION_ENABLED = 1
-} MbimMsTransmissionNotification;
+ MBIM_TRANSMISSION_NOTIFICATION_STATUS_DISABLED = 0,
+ MBIM_TRANSMISSION_NOTIFICATION_STATUS_ENABLED = 1
+} MbimTransmissionNotificationStatus;
/**
* MbimMsTransmissionState:
* @MBIM_MS_TRANSMISSION_STATE_INACTIVE: Modem was not actively transmitting data.
* @MBIM_MS_TRANSMISSION_STATE_ACTIVE: Modem was actively transmitting data.
*
- * Whether modem is having TX traffic every HysteresisTimer seconds.
+ * Whether modem is having TX traffic every hysteresis timeout.
*
* Since: 1.26
*/
typedef enum { /*< since=1.26 >*/
- MBIM_MS_TRANSMISSION_STATE_INACTIVE = 0,
- MBIM_MS_TRANSMISSION_STATE_ACTIVE = 1
-} MbimMsTransmissionState;
+ MBIM_TRANSMISSION_STATE_INACTIVE = 0,
+ MBIM_TRANSMISSION_STATE_ACTIVE = 1
+} MbimTransmissionState;
G_END_DECLS
@@ -1253,37 +1253,37 @@ typedef enum { /*< since=1.26 >*/
} MbimSarWifiHardwareState;
/**
- * MbimMsTransmissionNotification:
- * @MBIM_MS_TRANSMISSION_NOTIFICATION_DISABLED: Notification disabled.
- * @MBIM_MS_TRANSMISSION_NOTIFICATION_ENABLED: Notification enabled.
+ * MbimTransmissionNotificationStatus:
+ * @MBIM_TRANSMISSION_NOTIFICATION_STATUS_DISABLED: Notification disabled.
+ * @MBIM_TRANSMISSION_NOTIFICATION_STATUS_ENABLED: Notification enabled.
*
* Whether modem channel transmission status notification is disabled or enabled.
@@ -1253,37 +1253,37 @@ typedef enum { /*< since=1.26 >*/
/**
- * MbimMsTransmissionState:
- * @MBIM_MS_TRANSMISSION_STATE_INACTIVE: Modem was not actively transmitting data.
- * @MBIM_MS_TRANSMISSION_STATE_ACTIVE: Modem was actively transmitting data.
+ * MbimTransmissionState:
+ * @MBIM_TRANSMISSION_STATE_INACTIVE: Modem was not actively transmitting data.
+ * @MBIM_TRANSMISSION_STATE_ACTIVE: Modem was actively transmitting data.
*